==> DQScriptsDemo_0_2_1.zip: DQScriptsDemo_0_2_1/rgss-lib/dq/menu/Window_Item_Menu.rb <==
#==============================================================================
#  Window_Item_Menu
#------------------------------------------------------------------------------
# ACej[EBhE
# Copyright (C) 2005 fukuyama
#==============================================================================

module DQ

class Window_Item_Menu < Window_Menu
  include Window_Tree_Module
  #--------------------------------------------------------------------------
  # 
  #--------------------------------------------------------------------------
  def initialize(parent)
    @title = 'ǂH'
    actor = parent.get_window(Window_Actor_Menu_Item).actor
    item = parent.get_window(Window_Item).item
    add_menu('',:use_item)
    add_menu('킽',:trade_item)
    if actor.is_a? Game_Actor
      if Item_Facade.actor_equip?(item,actor)
        add_menu('͂',:remove_equip_item)
      else
        add_menu('',:equip_item)
      end
    end
    add_menu('Ă',:throw_item)
    add_menu('߂',:exit_window)
    @index = 0
    super(parent)
    # ʒu̐ݒ
    self.screen_bottom(16 + 32)
    self.right = parent.left
  end
  #--------------------------------------------------------------------------
  # XV
  #--------------------------------------------------------------------------
  def update
    if @message_end
      dispose
      get_window(Window_Item).refresh
      return
    end
    super
  end
  #--------------------------------------------------------------------------
  # 
  #--------------------------------------------------------------------------
  def use_item
    owner_actor = get_window(Window_Actor_Menu_Item).actor
    owner_actor = get_window(Window_Actor_Menu_Item).backpack if owner_actor.nil?
		item = Item_Facade.get_use_item(get_window(Window_Item).item)
		if item.nil?
		  item = get_window(Window_Item).item
      if not Item_Facade.item_can_use?(item,owner_actor)
        name = ''
        if owner_actor.class.method_defined?('name')
          name = owner_actor.name
	      else
          name = $game_party.actors[0].name
        end
        e = Script_Event.new
        e.message("#{name}́A#{item.name}B")
        e.message("AȂɂȂB")
        e.brank
        $scene.interpreter.setup e.event_commands, 0
        @message_end = true
        return
      end
	  end
    if item.scope_all?    # ΏۂŜ̏ꍇ
      if not Item_Facade.item_can_use?(item,owner_actor)
        e = Script_Event.new
        e.message("#{owner_actor.name}́A#{item.name}B")
        e.message("AȂɂȂB")
        e.brank
        $scene.interpreter.setup e.event_commands, 0
        @message_end = true
        return
      end
      used = Item_Facade.use_item(item,owner_actor,$game_party.actors)
      # ACegꍇ
      if used
        # Sł̏ꍇ
        if $game_party.all_dead?
          # Q[I[o[ʂɐ؂ւ
          $scene = Scene_Gameover.new
          return
        end
        # RCxg ID L̏ꍇ
        if item.common_event_id > 0
          # RCxgĂяo\
          $game_temp.common_event_id = item.common_event_id
          # }bvʂɐ؂ւ
          $scene = Scene_Map.new
          return
        end
        e = Script_Event.new
        e.message("#{$game_party.actors[0].name}́@#{item.name}B")

# TOOD ACeɃbZ[Wݒ肷Kv

        e.brank
        $scene.interpreter.setup e.event_commands, 0
        @message_end = true
        return
      end
    else                  # ΏۂP̂̏ꍇ
      window = Window_Actor_Menu_Item_Use.new(self)
      add_child window
      set_active_window(window.class)
    end
  end
  #--------------------------------------------------------------------------
  # 킽
  #--------------------------------------------------------------------------
  def trade_item
    window = Window_Actor_Menu_Item_Trade.new(self,'ɁH')
    add_child window
    set_active_window(window.class)
  end
  #--------------------------------------------------------------------------
  # 
  #--------------------------------------------------------------------------
  def equip_item
    actor = get_window(Window_Actor_Menu_Item).actor
    item = get_window(Window_Item).item
    if item.is_a?(Game_Item)
      msg = "#{item.name}\\n邱Ƃ́@ł܂B"
    elsif not Item_Facade.equippable?(item,actor)
      msg = "#{actor.name}́@#{item.name}\\n邱ƂłȂB"
    elsif (not actor.nil?) and (not item.nil?)
      actor.equip_item(item)
      # SE
      equip_se
      msg = "#{actor.name}́A#{item.name}\\nB"
    end
    e = Script_Event.new
    e.message(msg)
    e.brank
    $scene.interpreter.setup e.event_commands, 0
    @message_end = true
  end
  #--------------------------------------------------------------------------
  # ͂
  #--------------------------------------------------------------------------
  def remove_equip_item
    actor = get_window(Window_Actor_Menu_Item).actor
    item = get_window(Window_Item).item
    if (not actor.nil?) and (not item.nil?)
      actor.remove_equip_item(item)
      # SE
      equip_se
      e = Script_Event.new
      e.message("#{actor.name}́A#{item.name}\\n͂B")
      e.brank
      $scene.interpreter.setup e.event_commands, 0
      @message_end = true
    end
  end
  #--------------------------------------------------------------------------
  # Ă
  #--------------------------------------------------------------------------
  def throw_item
    actor = get_window(Window_Actor_Menu_Item).actor
    if actor.nil?
      actor = get_window(Window_Actor_Menu_Item).backpack
    end
    item = get_window(Window_Item).item
    if Item_Facade.item_can_throw?(item,actor)
       e = Script_Event.new
       e.message("#{item.name}\\n̂ĂĂłH\\n")

       e.branch_start(['͂',''],2)

       e.branch_item(0)
       e.method_call(Item_Facade.method(:throw_item),item,actor)
       if actor.class.method_defined?('name')
         e.message("#{actor.name}́@#{item.name}ȂĂB")
       else
         e.message("#{item.name}ȂĂB")
       end

       e.branch_end
       e.brank
       $scene.interpreter.setup e.event_commands, 0
    else
      e = Script_Event.new
      e.message("@̂ĂȂā@ƂłȂI")
      e.brank
      $scene.interpreter.setup e.event_commands, 0
    end
    @message_end = true
  end
  #--------------------------------------------------------------------------
  # ߂
  #--------------------------------------------------------------------------
  def exit_window
    cancel_se
    if not top_window.disposed?
      top_window.dispose
    end
  end
  #---------------------------------------------------------------------------
  # Rec̍쐬
  def _contents_width
    return ACTOR_MENU_WIDTH
  end
end

end

==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/menu/Window_Item_Menu.rb <==
#==============================================================================
#  Window_Item_Menu
#------------------------------------------------------------------------------
# ACej[EBhE
# Copyright (C) 2005 fukuyama
#==============================================================================

module DQ

class Window_Item_Menu < Window_Menu
  include Window_Tree_Module
  include Menu_Log_Item_Module
  #--------------------------------------------------------------------------
  # 
  #--------------------------------------------------------------------------
  def initialize(parent)
    @title = 'ǂH'
    actor = parent.get_window(Window_Actor_Menu_Item).actor
    item = parent.get_window(Window_Item).item
    add_menu('',:use_item)
    add_menu('킽',:trade_item)
    if actor.is_a? Game_Actor
      if Item_Facade.actor_equip?(item,actor)
        add_menu('͂',:remove_equip_item)
      else
        add_menu('',:equip_item)
      end
    end
    add_menu('Ă',:throw_item)
    add_menu('߂',:exit_window)
    @index = 0
    super(parent)
    # ʒu̐ݒ
    self.screen_bottom(16 + 32)
    self.right = parent.left
  end
  #--------------------------------------------------------------------------
  # XV
  #--------------------------------------------------------------------------
  def update
    if @message_end
      dispose
      get_window(Window_Item).refresh
      return
    end
    super
  end
  #--------------------------------------------------------------------------
  # 
  #--------------------------------------------------------------------------
  def use_item
    owner_actor = get_window(Window_Actor_Menu_Item).actor
    owner_actor = get_window(Window_Actor_Menu_Item).backpack if owner_actor.nil?
    item = Item_Facade.get_use_item(get_window(Window_Item).item)
    # ȂACeꍇ
    if item.nil?
      item = get_window(Window_Item).item
      if not Item_Facade.item_can_use?(item,owner_actor)
        menu_log_use_item_miss(item,owner_actor)
        @message_end = true
        return
      end
	  end
    if item.scope_all?    # ΏۂŜ̏ꍇ
      if not Item_Facade.item_can_use?(item,owner_actor)
        menu_log_use_item_miss(item,owner_actor)
        @message_end = true
        return
      end
      used = Item_Facade.use_item(item,owner_actor,$game_party.actors)
      # ACegꍇ
      if used
        menu_log_use_item(item,owner_actor,$game_party.actors)
        @message_end = true
        return
      end
    else                  # ΏۂP̂̏ꍇ
      window = Window_Actor_Menu_Item_Use.new(self)
      add_child window
      set_active_window(window.class)
    end
  end
  #--------------------------------------------------------------------------
  # 킽
  #--------------------------------------------------------------------------
  def trade_item
    actor = get_window(Window_Actor_Menu_Item).actor
    item = parent.get_window(Window_Item).item
    # Œ肳Ăꍇ
    if Item_Facade.actor_equip?(item,actor)
      if Item_Facade.equip_fix?(item,actor)
        menu_log_trade_item_fix(item,actor)
        @message_end = true
        return
      end
    end
    window = Window_Actor_Menu_Item_Trade.new(self,'ɁH')
    add_child window
    set_active_window(window.class)
  end
  #--------------------------------------------------------------------------
  # 
  #--------------------------------------------------------------------------
  def equip_item
    actor = get_window(Window_Actor_Menu_Item).actor
    item = get_window(Window_Item).item
    # Œ肳Ăꍇ
    if Item_Facade.equip_fix?(item,actor)
      menu_log_equip_item_fix(item,actor)
      @message_end = true
      return
    end
    if item.is_a?(Game_Item)
      # O
      menu_log_equip_item_error(item)
    elsif not Item_Facade.equippable?(item,actor)
      # O
      menu_log_equip_item_actor_error(item,actor)
    elsif (not actor.nil?) and (not item.nil?)
      actor.equip_item(item)
      # SE
      equip_se
      # O
      menu_log_equip_item(item,actor)
    end
    @message_end = true
  end
  #--------------------------------------------------------------------------
  # ͂
  #--------------------------------------------------------------------------
  def remove_equip_item
    actor = get_window(Window_Actor_Menu_Item).actor
    item = get_window(Window_Item).item
    if (not actor.nil?) and (not item.nil?)
      # Œ肳Ăꍇ
      if Item_Facade.equip_fix?(item,actor)
        menu_log_remove_equip_item_fix(item,actor)
        @message_end = true
        return
      end
      actor.remove_equip_item(item)
      # SE
      equip_se
      # O
      menu_log_remove_equip_item(item,actor)
      @message_end = true
    end
  end
  #--------------------------------------------------------------------------
  # Ă
  #--------------------------------------------------------------------------
  def throw_item
    actor = get_window(Window_Actor_Menu_Item).actor
    if actor.nil?
      actor = get_window(Window_Actor_Menu_Item).backpack
    end
    item = get_window(Window_Item).item
    if Item_Facade.item_can_throw?(item,actor)
      case actor
      when Game_Actor
        # Œ肳Ăꍇ
        if Item_Facade.actor_equip?(item,actor)
          if Item_Facade.equip_fix?(item,actor)
            menu_log_throw_item_fix(item,actor)
            @message_end = true
            return
          end
        end
        menu_log_throw_item_actor(item,actor)
      when Game_Party
        menu_log_throw_item_party(item,actor)
      end
    else
      menu_log_throw_item_error(item,actor)
    end
    @message_end = true
  end
  #--------------------------------------------------------------------------
  # ߂
  #--------------------------------------------------------------------------
  def exit_window
    cancel_se
    if not top_window.disposed?
      top_window.dispose
    end
  end
  #---------------------------------------------------------------------------
  # Rec̍쐬
  def _contents_width
    return ACTOR_MENU_WIDTH
  end
end

end
